# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x61tasource.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x11\x44\x61taSourceRequest\x12\x11\n\tdsourceID\x18\x01 \x03(\t\x12\x14\n\x0crenameDsrcID\x18\x02 \x01(\t\"\xae\x01\n\x18\x44\x61taSourceSetSaveRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12\x11\n\tdsourceID\x18\x03 \x01(\t\x12\x0b\n\x03uID\x18\x04 \x01(\t\x12(\n\x08\x66ileType\x18\x05 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x0f\n\x07isForce\x18\x06 \x01(\x08\x12\x17\n\x0fisBackgroundKPI\x18\x07 \x01(\x08\"%\n\x11\x44\x61taSourceIDReply\x12\x10\n\x08sortedID\x18\x01 \x03(\t\"U\n\x16\x44\x61taSourceSetSaveReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12(\n\x06status\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus\"\xae\x01\n\x13\x44\x61taSourceStatusMap\x12\x39\n\x07\x64source\x18\x01 \x03(\x0b\x32(.allego.DataSourceStatusMap.DsourceEntry\x12\x12\n\norderedIDs\x18\x02 \x03(\t\x1aH\n\x0c\x44sourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus:\x02\x38\x01\"\xa1\x03\n\x1f\x43opyRemoveDataSourceFileRequest\x12\x45\n\x04many\x18\x01 \x01(\x0b\x32\x35.allego.CopyRemoveDataSourceFileRequest.MultipleFilesH\x00\x12>\n\x03one\x18\x02 \x01(\x0b\x32/.allego.CopyRemoveDataSourceFileRequest.OneFileH\x00\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\x1at\n\rMultipleFiles\x12#\n\x03src\x18\x01 \x03(\x0b\x32\x16.allego.FileDescriptor\x12\x10\n\x08\x64\x65stPath\x18\x02 \x01(\t\x12,\n\x0c\x64\x65stFileType\x18\x03 \x01(\x0e\x32\x16.allego.RadixFileTypes\x1aT\n\x07OneFile\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x01(\x0b\x32\x16.allego.FileDescriptorB\x06\n\x04\x64\x65sc\"\xf8\x02\n\x15\x44\x61taSourceFileSetStat\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x1b\n\x13numBytesPrimaryData\x18\x02 \x02(\x03\x12\x18\n\x10numBytesMetaData\x18\x03 \x02(\x03\x12\x10\n\x08numBytes\x18\x04 \x02(\x03\x12\x16\n\x0eisMetadataFile\x18\x05 \x02(\x08\x12-\n\ttimeStamp\x18\x06 \x02(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnumChannels\x18\x07 \x02(\x05\x12\x13\n\x0b\x64urationSec\x18\x08 \x02(\x01\x12\x12\n\ndatasetUID\x18\t \x02(\t\x12\x17\n\x0f\x64\x61tasetChecksum\x18\n \x01(\t\x12\x19\n\x11\x64\x61tasetProvenance\x18\x0b \x03(\t\x12\x12\n\nsampleRate\x18\x0c \x02(\x05\x12\x37\n\x0e\x62\x61\x63kgroundProc\x18\r \x01(\x0b\x32\x1f.allego.BackgroundProcessStatus\"\x82\x02\n\rCpRmMvLsReply\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x12\n\nnumDsource\x18\x02 \x02(\x05\x12\x10\n\x08numBytes\x18\x03 \x02(\x03\x12\x10\n\x08\x64\x65stPath\x18\x04 \x02(\t\x12\x35\n\x07\x64source\x18\x05 \x03(\x0b\x32$.allego.CpRmMvLsReply.DataSourceInfo\x12\x0b\n\x03msg\x18\x06 \x01(\t\x1a\x63\n\x0e\x44\x61taSourceInfo\x12$\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12+\n\x04stat\x18\x02 \x02(\x0b\x32\x1d.allego.DataSourceFileSetStat\"y\n\x17\x42\x61\x63kgroundProcessStatus\x12\x0b\n\x03uID\x18\x01 \x02(\t\x12\x14\n\x0c\x66racComplete\x18\x02 \x01(\x01\x12\x16\n\x0e\x65lapsedTimeSec\x18\x03 \x01(\x01\x12#\n\x1b\x65stimatedCompletionWallTime\x18\x04 \x01(\t\"\x8b\x01\n\x19MoveDataSourceFileRequest\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x02(\x0b\x32\x16.allego.FileDescriptor\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\"\xe7\x02\n\x10\x44\x61taSourceStatus\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08\x64uration\x18\x04 \x02(\x01\x12\r\n\x05shape\x18\x05 \x03(\x03\x12(\n\x0bsignalGroup\x18\x06 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x17\n\x0fnumTotalSamples\x18\x07 \x02(\x03\x12\x11\n\tsizeBytes\x18\x08 \x02(\x03\x12\x12\n\nsampleFreq\x18\t \x02(\x01\x12\x0b\n\x03uid\x18\n \x02(\t\x12\x16\n\x0e\x64\x61taSourceType\x18\x0b \x02(\t\x12\x10\n\x08\x66ileType\x18\x0c \x02(\t\x12\x0c\n\x04mode\x18\r \x02(\t\x12\r\n\x05label\x18\x0e \x02(\t\x12\x0c\n\x04path\x18\x0f \x02(\t\x12\x14\n\x0c\x62\x61seFileName\x18\x10 \x02(\t\"\xbf\x01\n\x10\x44\x61taSourceParams\x12\x12\n\nsampleFreq\x18\x01 \x02(\x01\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x10\n\x08\x64uration\x18\x03 \x02(\x01\x12%\n\x04type\x18\x05 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x35\n\x0e\x64\x61tasourceType\x18\x06 \x01(\x0e\x32\x1d.allego.RadiensDatasourceType\x12\x14\n\x0c\x64\x61tasourceID\x18\x07 \x01(\t\".\n\x10ImpedanceRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\"\x85\x01\n\tImpedance\x12\x34\n\nimpedances\x18\x01 \x03(\x0b\x32 .allego.Impedance.ImpedanceValue\x1a\x42\n\x0eImpedanceValue\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x0c\n\x04zMag\x18\x02 \x02(\x01\x12\x0e\n\x06zPhase\x18\x03 \x02(\x01*<\n\x15RadiensDatasourceType\x12\x07\n\x03\x41NY\x10\x00\x12\x0e\n\nTIMESERIES\x10\x01\x12\n\n\x06SPIKES\x10\x02\x42\x15Z\x13internal/radix/grpc')

_RADIENSDATASOURCETYPE = DESCRIPTOR.enum_types_by_name['RadiensDatasourceType']
RadiensDatasourceType = enum_type_wrapper.EnumTypeWrapper(_RADIENSDATASOURCETYPE)
ANY = 0
TIMESERIES = 1
SPIKES = 2


_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_DATASOURCESETSAVEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceSetSaveRequest']
_DATASOURCEIDREPLY = DESCRIPTOR.message_types_by_name['DataSourceIDReply']
_DATASOURCESETSAVEREPLY = DESCRIPTOR.message_types_by_name['DataSourceSetSaveReply']
_DATASOURCESTATUSMAP = DESCRIPTOR.message_types_by_name['DataSourceStatusMap']
_DATASOURCESTATUSMAP_DSOURCEENTRY = _DATASOURCESTATUSMAP.nested_types_by_name['DsourceEntry']
_COPYREMOVEDATASOURCEFILEREQUEST = DESCRIPTOR.message_types_by_name['CopyRemoveDataSourceFileRequest']
_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES = _COPYREMOVEDATASOURCEFILEREQUEST.nested_types_by_name['MultipleFiles']
_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE = _COPYREMOVEDATASOURCEFILEREQUEST.nested_types_by_name['OneFile']
_DATASOURCEFILESETSTAT = DESCRIPTOR.message_types_by_name['DataSourceFileSetStat']
_CPRMMVLSREPLY = DESCRIPTOR.message_types_by_name['CpRmMvLsReply']
_CPRMMVLSREPLY_DATASOURCEINFO = _CPRMMVLSREPLY.nested_types_by_name['DataSourceInfo']
_BACKGROUNDPROCESSSTATUS = DESCRIPTOR.message_types_by_name['BackgroundProcessStatus']
_MOVEDATASOURCEFILEREQUEST = DESCRIPTOR.message_types_by_name['MoveDataSourceFileRequest']
_DATASOURCESTATUS = DESCRIPTOR.message_types_by_name['DataSourceStatus']
_DATASOURCEPARAMS = DESCRIPTOR.message_types_by_name['DataSourceParams']
_IMPEDANCEREQUEST = DESCRIPTOR.message_types_by_name['ImpedanceRequest']
_IMPEDANCE = DESCRIPTOR.message_types_by_name['Impedance']
_IMPEDANCE_IMPEDANCEVALUE = _IMPEDANCE.nested_types_by_name['ImpedanceValue']
DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

DataSourceSetSaveRequest = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveRequest)
  })
_sym_db.RegisterMessage(DataSourceSetSaveRequest)

DataSourceIDReply = _reflection.GeneratedProtocolMessageType('DataSourceIDReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEIDREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceIDReply)
  })
_sym_db.RegisterMessage(DataSourceIDReply)

DataSourceSetSaveReply = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveReply)
  })
_sym_db.RegisterMessage(DataSourceSetSaveReply)

DataSourceStatusMap = _reflection.GeneratedProtocolMessageType('DataSourceStatusMap', (_message.Message,), {

  'DsourceEntry' : _reflection.GeneratedProtocolMessageType('DsourceEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASOURCESTATUSMAP_DSOURCEENTRY,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap.DsourceEntry)
    })
  ,
  'DESCRIPTOR' : _DATASOURCESTATUSMAP,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap)
  })
_sym_db.RegisterMessage(DataSourceStatusMap)
_sym_db.RegisterMessage(DataSourceStatusMap.DsourceEntry)

CopyRemoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('CopyRemoveDataSourceFileRequest', (_message.Message,), {

  'MultipleFiles' : _reflection.GeneratedProtocolMessageType('MultipleFiles', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.MultipleFiles)
    })
  ,

  'OneFile' : _reflection.GeneratedProtocolMessageType('OneFile', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.OneFile)
    })
  ,
  'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.MultipleFiles)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.OneFile)

DataSourceFileSetStat = _reflection.GeneratedProtocolMessageType('DataSourceFileSetStat', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEFILESETSTAT,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceFileSetStat)
  })
_sym_db.RegisterMessage(DataSourceFileSetStat)

CpRmMvLsReply = _reflection.GeneratedProtocolMessageType('CpRmMvLsReply', (_message.Message,), {

  'DataSourceInfo' : _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPRMMVLSREPLY_DATASOURCEINFO,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply.DataSourceInfo)
    })
  ,
  'DESCRIPTOR' : _CPRMMVLSREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply)
  })
_sym_db.RegisterMessage(CpRmMvLsReply)
_sym_db.RegisterMessage(CpRmMvLsReply.DataSourceInfo)

BackgroundProcessStatus = _reflection.GeneratedProtocolMessageType('BackgroundProcessStatus', (_message.Message,), {
  'DESCRIPTOR' : _BACKGROUNDPROCESSSTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.BackgroundProcessStatus)
  })
_sym_db.RegisterMessage(BackgroundProcessStatus)

MoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('MoveDataSourceFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.MoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(MoveDataSourceFileRequest)

DataSourceStatus = _reflection.GeneratedProtocolMessageType('DataSourceStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatus)
  })
_sym_db.RegisterMessage(DataSourceStatus)

DataSourceParams = _reflection.GeneratedProtocolMessageType('DataSourceParams', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEPARAMS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceParams)
  })
_sym_db.RegisterMessage(DataSourceParams)

ImpedanceRequest = _reflection.GeneratedProtocolMessageType('ImpedanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPEDANCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.ImpedanceRequest)
  })
_sym_db.RegisterMessage(ImpedanceRequest)

Impedance = _reflection.GeneratedProtocolMessageType('Impedance', (_message.Message,), {

  'ImpedanceValue' : _reflection.GeneratedProtocolMessageType('ImpedanceValue', (_message.Message,), {
    'DESCRIPTOR' : _IMPEDANCE_IMPEDANCEVALUE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.Impedance.ImpedanceValue)
    })
  ,
  'DESCRIPTOR' : _IMPEDANCE,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.Impedance)
  })
_sym_db.RegisterMessage(Impedance)
_sym_db.RegisterMessage(Impedance.ImpedanceValue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _DATASOURCESTATUSMAP_DSOURCEENTRY._options = None
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_options = b'8\001'
  _RADIENSDATASOURCETYPE._serialized_start=2682
  _RADIENSDATASOURCETYPE._serialized_end=2742
  _DATASOURCEREQUEST._serialized_start=75
  _DATASOURCEREQUEST._serialized_end=135
  _DATASOURCESETSAVEREQUEST._serialized_start=138
  _DATASOURCESETSAVEREQUEST._serialized_end=312
  _DATASOURCEIDREPLY._serialized_start=314
  _DATASOURCEIDREPLY._serialized_end=351
  _DATASOURCESETSAVEREPLY._serialized_start=353
  _DATASOURCESETSAVEREPLY._serialized_end=438
  _DATASOURCESTATUSMAP._serialized_start=441
  _DATASOURCESTATUSMAP._serialized_end=615
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_start=543
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_end=615
  _COPYREMOVEDATASOURCEFILEREQUEST._serialized_start=618
  _COPYREMOVEDATASOURCEFILEREQUEST._serialized_end=1035
  _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES._serialized_start=825
  _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES._serialized_end=941
  _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE._serialized_start=943
  _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE._serialized_end=1027
  _DATASOURCEFILESETSTAT._serialized_start=1038
  _DATASOURCEFILESETSTAT._serialized_end=1414
  _CPRMMVLSREPLY._serialized_start=1417
  _CPRMMVLSREPLY._serialized_end=1675
  _CPRMMVLSREPLY_DATASOURCEINFO._serialized_start=1576
  _CPRMMVLSREPLY_DATASOURCEINFO._serialized_end=1675
  _BACKGROUNDPROCESSSTATUS._serialized_start=1677
  _BACKGROUNDPROCESSSTATUS._serialized_end=1798
  _MOVEDATASOURCEFILEREQUEST._serialized_start=1801
  _MOVEDATASOURCEFILEREQUEST._serialized_end=1940
  _DATASOURCESTATUS._serialized_start=1943
  _DATASOURCESTATUS._serialized_end=2302
  _DATASOURCEPARAMS._serialized_start=2305
  _DATASOURCEPARAMS._serialized_end=2496
  _IMPEDANCEREQUEST._serialized_start=2498
  _IMPEDANCEREQUEST._serialized_end=2544
  _IMPEDANCE._serialized_start=2547
  _IMPEDANCE._serialized_end=2680
  _IMPEDANCE_IMPEDANCEVALUE._serialized_start=2614
  _IMPEDANCE_IMPEDANCEVALUE._serialized_end=2680
# @@protoc_insertion_point(module_scope)
