# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radiens_dev.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11radiens_dev.proto\x12\x06\x61llego\"\xc0\x01\n\x14SpkSortTrainerNewReq\x12\x33\n\x07\x64\x61taset\x18\x01 \x02(\x0b\x32\".allego.SpkSortTrainerDatasetParam\x12=\n\x08training\x18\x02 \x02(\x0b\x32+.allego.SpkSortTrainerNetworkTrainingParams\x12\x34\n\x05store\x18\x03 \x02(\x0b\x32%.allego.SpkSortTrainerStoreDescriptor\"l\n\x1cSpkSortTrainerDeleteModelReq\x12\x35\n\x07release\x18\x01 \x01(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\x12\x15\n\risDeleteNamed\x18\x02 \x01(\x08\"\xb6\x03\n\x1aSpkSortTrainerDatasetParam\x12\x14\n\x0c\x62ioPathTrain\x18\x01 \x03(\t\x12\x18\n\x10\x62ioBaseNameTrain\x18\x02 \x03(\t\x12\x19\n\x11\x62ioPathValidation\x18\x03 \x03(\t\x12\x1d\n\x15\x62ioBaseNameValidation\x18\x04 \x03(\t\x12\x13\n\x0b\x62ioPathTest\x18\x05 \x03(\t\x12\x17\n\x0f\x62ioBaseNameTest\x18\x06 \x03(\t\x12\x14\n\x0cnumNeighbors\x18\x07 \x02(\x05\x12\x10\n\x08radiusUm\x18\x08 \x02(\x01\x12\x19\n\x11maxNumSamplesTest\x18\t \x02(\x03\x12\x1a\n\x12networkMaskingFrac\x18\n \x02(\x01\x12 \n\x18networkInitWeightsStdDev\x18\x0b \x02(\x01\x12\x1d\n\x15networkInitBiasStdDev\x18\x0c \x02(\x01\x12\x17\n\x0fnetworkL1lambda\x18\r \x02(\x01\x12*\n\"networkHiddenLayerShapeRelInputDim\x18\x0e \x03(\x01\x12\x1b\n\x13networkNumFeatures2\x18\x0f \x02(\x05\"\xbd\x01\n#SpkSortTrainerNetworkTrainingParams\x12\x11\n\tnumEpochs\x18\x01 \x02(\x05\x12\x15\n\rminibatchSize\x18\x02 \x02(\x05\x12\x15\n\rmaxNumSamples\x18\x03 \x02(\x03\x12\r\n\x05\x61lpha\x18\x04 \x02(\x01\x12\x11\n\talphaBias\x18\x05 \x02(\x01\x12\x18\n\x10\x65rrorTolPretrain\x18\x06 \x02(\x01\x12\x19\n\x11numSamplesTestMSE\x18\x07 \x02(\x05\"\x87\x02\n\x1dSpkSortTrainerStoreDescriptor\x12\x13\n\x0b\x62rainRegion\x18\x01 \x02(\t\x12\x36\n\x0bnetworkSize\x18\x02 \x02(\x0e\x32!.allego.SpkSortTrainerNetworkSize\x12\x39\n\nnbrPattern\x18\x03 \x02(\x0e\x32%.allego.SpkSortTrainerNeighborPattern\x12\x11\n\tnetworkID\x18\x04 \x02(\t\x12\x14\n\x0cnumNeighbors\x18\x05 \x02(\x05\x12\x35\n\x07release\x18\x06 \x02(\x0e\x32$.allego.SpkSortTrainerNetworkRelease\"(\n\x18SpkSortTrainerSetModeReq\x12\x0c\n\x04mode\x18\x01 \x02(\x05\"\x81\x01\n\x14SpkSortTrainerCmdReq\x12;\n\x03\x63md\x18\x01 \x02(\x0e\x32..allego.SpkSortTrainerCmdReq.SpkSortTrainerCmd\",\n\x11SpkSortTrainerCmd\x12\n\n\x06\x43MD_ON\x10\x00\x12\x0b\n\x07\x43MD_OFF\x10\x01\",\n\x19SpkSortTrainerStatusReply\x12\x0f\n\x07msgJson\x18\x01 \x02(\x0c*\x81\x01\n\x19SpkSortTrainerNetworkSize\x12\x14\n\x10SST_SIZE_DEFAULT\x10\x00\x12\x10\n\x0cSST_SIZE_ARB\x10\x01\x12\x12\n\x0eSST_SIZE_SMALL\x10\x02\x12\x14\n\x10SST_SIZE_NOMINAL\x10\x03\x12\x12\n\x0eSST_SIZE_LARGE\x10\x04*\xa1\x01\n\x1dSpkSortTrainerNeighborPattern\x12\x17\n\x13SST_PATTERN_DEFAULT\x10\x00\x12\x13\n\x0fSST_PATTERN_ARB\x10\x01\x12\x14\n\x10SST_PATTERN_DIST\x10\x02\x12\x1d\n\x19SST_PATTERN_SPATIAL_TIGHT\x10\x03\x12\x1d\n\x19SST_PATTERN_SPATIAL_LOOSE\x10\x04*\xe3\x01\n\x1cSpkSortTrainerNetworkRelease\x12\x17\n\x13SST_NET_RELEASE_ANY\x10\x00\x12\x17\n\x13SST_NET_RELEASE_DEV\x10\x01\x12\x1b\n\x17SST_NET_RELEASE_DEV_MOD\x10\x02\x12\x18\n\x14SST_NET_RELEASE_PROD\x10\x03\x12\x1c\n\x18SST_NET_RELEASE_PROD_MOD\x10\x04\x12\x1b\n\x17SST_NET_RELEASE_SANDBOX\x10\x05\x12\x1f\n\x1bSST_NET_RELEASE_SANDBOX_MOD\x10\x06\x42\x15Z\x13internal/radix/grpc')

_SPKSORTTRAINERNETWORKSIZE = DESCRIPTOR.enum_types_by_name['SpkSortTrainerNetworkSize']
SpkSortTrainerNetworkSize = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNETWORKSIZE)
_SPKSORTTRAINERNEIGHBORPATTERN = DESCRIPTOR.enum_types_by_name['SpkSortTrainerNeighborPattern']
SpkSortTrainerNeighborPattern = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNEIGHBORPATTERN)
_SPKSORTTRAINERNETWORKRELEASE = DESCRIPTOR.enum_types_by_name['SpkSortTrainerNetworkRelease']
SpkSortTrainerNetworkRelease = enum_type_wrapper.EnumTypeWrapper(_SPKSORTTRAINERNETWORKRELEASE)
SST_SIZE_DEFAULT = 0
SST_SIZE_ARB = 1
SST_SIZE_SMALL = 2
SST_SIZE_NOMINAL = 3
SST_SIZE_LARGE = 4
SST_PATTERN_DEFAULT = 0
SST_PATTERN_ARB = 1
SST_PATTERN_DIST = 2
SST_PATTERN_SPATIAL_TIGHT = 3
SST_PATTERN_SPATIAL_LOOSE = 4
SST_NET_RELEASE_ANY = 0
SST_NET_RELEASE_DEV = 1
SST_NET_RELEASE_DEV_MOD = 2
SST_NET_RELEASE_PROD = 3
SST_NET_RELEASE_PROD_MOD = 4
SST_NET_RELEASE_SANDBOX = 5
SST_NET_RELEASE_SANDBOX_MOD = 6


_SPKSORTTRAINERNEWREQ = DESCRIPTOR.message_types_by_name['SpkSortTrainerNewReq']
_SPKSORTTRAINERDELETEMODELREQ = DESCRIPTOR.message_types_by_name['SpkSortTrainerDeleteModelReq']
_SPKSORTTRAINERDATASETPARAM = DESCRIPTOR.message_types_by_name['SpkSortTrainerDatasetParam']
_SPKSORTTRAINERNETWORKTRAININGPARAMS = DESCRIPTOR.message_types_by_name['SpkSortTrainerNetworkTrainingParams']
_SPKSORTTRAINERSTOREDESCRIPTOR = DESCRIPTOR.message_types_by_name['SpkSortTrainerStoreDescriptor']
_SPKSORTTRAINERSETMODEREQ = DESCRIPTOR.message_types_by_name['SpkSortTrainerSetModeReq']
_SPKSORTTRAINERCMDREQ = DESCRIPTOR.message_types_by_name['SpkSortTrainerCmdReq']
_SPKSORTTRAINERSTATUSREPLY = DESCRIPTOR.message_types_by_name['SpkSortTrainerStatusReply']
_SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD = _SPKSORTTRAINERCMDREQ.enum_types_by_name['SpkSortTrainerCmd']
SpkSortTrainerNewReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerNewReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERNEWREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerNewReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerNewReq)

SpkSortTrainerDeleteModelReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerDeleteModelReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERDELETEMODELREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerDeleteModelReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerDeleteModelReq)

SpkSortTrainerDatasetParam = _reflection.GeneratedProtocolMessageType('SpkSortTrainerDatasetParam', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERDATASETPARAM,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerDatasetParam)
  })
_sym_db.RegisterMessage(SpkSortTrainerDatasetParam)

SpkSortTrainerNetworkTrainingParams = _reflection.GeneratedProtocolMessageType('SpkSortTrainerNetworkTrainingParams', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERNETWORKTRAININGPARAMS,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerNetworkTrainingParams)
  })
_sym_db.RegisterMessage(SpkSortTrainerNetworkTrainingParams)

SpkSortTrainerStoreDescriptor = _reflection.GeneratedProtocolMessageType('SpkSortTrainerStoreDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSTOREDESCRIPTOR,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerStoreDescriptor)
  })
_sym_db.RegisterMessage(SpkSortTrainerStoreDescriptor)

SpkSortTrainerSetModeReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerSetModeReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSETMODEREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerSetModeReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerSetModeReq)

SpkSortTrainerCmdReq = _reflection.GeneratedProtocolMessageType('SpkSortTrainerCmdReq', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERCMDREQ,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerCmdReq)
  })
_sym_db.RegisterMessage(SpkSortTrainerCmdReq)

SpkSortTrainerStatusReply = _reflection.GeneratedProtocolMessageType('SpkSortTrainerStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _SPKSORTTRAINERSTATUSREPLY,
  '__module__' : 'radiens_dev_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpkSortTrainerStatusReply)
  })
_sym_db.RegisterMessage(SpkSortTrainerStatusReply)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _SPKSORTTRAINERNETWORKSIZE._serialized_start=1454
  _SPKSORTTRAINERNETWORKSIZE._serialized_end=1583
  _SPKSORTTRAINERNEIGHBORPATTERN._serialized_start=1586
  _SPKSORTTRAINERNEIGHBORPATTERN._serialized_end=1747
  _SPKSORTTRAINERNETWORKRELEASE._serialized_start=1750
  _SPKSORTTRAINERNETWORKRELEASE._serialized_end=1977
  _SPKSORTTRAINERNEWREQ._serialized_start=30
  _SPKSORTTRAINERNEWREQ._serialized_end=222
  _SPKSORTTRAINERDELETEMODELREQ._serialized_start=224
  _SPKSORTTRAINERDELETEMODELREQ._serialized_end=332
  _SPKSORTTRAINERDATASETPARAM._serialized_start=335
  _SPKSORTTRAINERDATASETPARAM._serialized_end=773
  _SPKSORTTRAINERNETWORKTRAININGPARAMS._serialized_start=776
  _SPKSORTTRAINERNETWORKTRAININGPARAMS._serialized_end=965
  _SPKSORTTRAINERSTOREDESCRIPTOR._serialized_start=968
  _SPKSORTTRAINERSTOREDESCRIPTOR._serialized_end=1231
  _SPKSORTTRAINERSETMODEREQ._serialized_start=1233
  _SPKSORTTRAINERSETMODEREQ._serialized_end=1273
  _SPKSORTTRAINERCMDREQ._serialized_start=1276
  _SPKSORTTRAINERCMDREQ._serialized_end=1405
  _SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD._serialized_start=1361
  _SPKSORTTRAINERCMDREQ_SPKSORTTRAINERCMD._serialized_end=1405
  _SPKSORTTRAINERSTATUSREPLY._serialized_start=1407
  _SPKSORTTRAINERSTATUSREPLY._serialized_end=1451
# @@protoc_insertion_point(module_scope)
